from dg_sdk.request.v2_trade_acctpayment_acctlog_query_request import V2TradeAcctpaymentAcctlogQueryRequest
from dg_sdk.request.v2_trade_acctpayment_pay_query_request import V2TradeAcctpaymentPayQueryRequest
from dg_sdk.request.v2_trade_acctpayment_refund_request import V2TradeAcctpaymentRefundRequest
from dg_sdk.request.v2_trade_acctpayment_refund_query_request import V2TradeAcctpaymentRefundQueryRequest
from dg_sdk.request.v2_trade_acctpayment_pay_request import V2TradeAcctpaymentPayRequest
from dg_sdk.request.v2_trade_payment_zxe_unknownincome_dispose_request import V2TradePaymentZxeUnknownincomeDisposeRequest
from dg_sdk.request.v2_trade_payment_zxe_unknownincome_disposequery_request import V2TradePaymentZxeUnknownincomeDisposequeryRequest
from dg_sdk.request.v2_trade_payment_zxe_unknownincome_query_request import V2TradePaymentZxeUnknownincomeQueryRequest
from dg_sdk.request.v2_merchant_elec_card_bind_request import V2MerchantElecCardBindRequest
from dg_sdk.request.v2_merchant_elec_card_unbind_request import V2MerchantElecCardUnbindRequest
from dg_sdk.request.v2_merchant_elec_card_default_request import V2MerchantElecCardDefaultRequest
from dg_sdk.request.v2_bank_balance_query_request import V2BankBalanceQueryRequest
from dg_sdk.request.v2_trade_payrelation_apply_request import V2TradePayrelationApplyRequest
from dg_sdk.request.v2_trade_payment_zxe_acctdetail_query_request import V2TradePaymentZxeAcctdetailQueryRequest
from dg_sdk.request.v2_trade_payment_zxe_incash_query_request import V2TradePaymentZxeIncashQueryRequest
from dg_sdk.request.v2_trade_cardbin_query_request import V2TradeCardbinQueryRequest
from dg_sdk.request.v2_trade_settlement_query_request import V2TradeSettlementQueryRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_h5_request import V2TradeHostingPaymentPreorderH5Request
from dg_sdk.request.v2_trade_hosting_payment_queryorderinfo_request import V2TradeHostingPaymentQueryorderinfoRequest
from dg_sdk.request.v2_trade_hosting_payment_htrefund_request import V2TradeHostingPaymentHtrefundRequest
from dg_sdk.request.v2_trade_hosting_payment_queryrefundinfo_request import V2TradeHostingPaymentQueryrefundinfoRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_wx_request import V2TradeHostingPaymentPreorderWxRequest
from dg_sdk.request.v2_trade_hosting_payment_preorder_ali_request import V2TradeHostingPaymentPreorderAliRequest
from dg_sdk.request.v2_trade_settlement_surrogate_request import V2TradeSettlementSurrogateRequest
from dg_sdk.request.v2_quickbuckle_withhold_query_request import V2QuickbuckleWithholdQueryRequest
from dg_sdk.request.v2_quickbuckle_withhold_apply_request import V2QuickbuckleWithholdApplyRequest
from dg_sdk.request.v2_quickbuckle_withhold_page_get_request import V2QuickbuckleWithholdPageGetRequest
from dg_sdk.request.v2_trade_onlinepayment_withholdpay_request import V2TradeOnlinepaymentWithholdpayRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_bankmistake_apply_request import V2TradeOnlinepaymentTransferBankmistakeApplyRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_bankmistake_applyquery_request import V2TradeOnlinepaymentTransferBankmistakeApplyqueryRequest
from dg_sdk.request.v2_largeamt_bindcard_bind_request import V2LargeamtBindcardBindRequest
from dg_sdk.request.v2_largeamt_bindcard_query_request import V2LargeamtBindcardQueryRequest
from dg_sdk.request.v2_largeamt_bindcard_unbind_request import V2LargeamtBindcardUnbindRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_bankblotter_query_request import V2TradeOnlinepaymentTransferBankblotterQueryRequest
from dg_sdk.request.v2_merchant_busi_efpconfig_request import V2MerchantBusiEfpconfigRequest
from dg_sdk.request.v2_merchant_busi_efpdetail_request import V2MerchantBusiEfpdetailRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_request import V2TradeOnlinepaymentTransferAccountRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_close_request import V2TradeOnlinepaymentTransferAccountCloseRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_remittanceorder_request import V2TradeOnlinepaymentTransferRemittanceorderRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_remittance_request import V2TradeOnlinepaymentTransferRemittanceRequest
from dg_sdk.request.v2_trade_onlinepayment_transfer_account_query_request import V2TradeOnlinepaymentTransferAccountQueryRequest
from dg_sdk.request.v2_trade_settlement_enchashment_dmamt_query_request import V2TradeSettlementEnchashmentDmamtQueryRequest
from dg_sdk.request.v2_trade_payment_getelectronicreceipt_request import V2TradePaymentGetelectronicreceiptRequest
from dg_sdk.request.v2_trade_electron_receipts_customentrances_create_request import V2TradeElectronReceiptsCustomentrancesCreateRequest
from dg_sdk.request.v2_trade_electron_receipts_customentrances_query_request import V2TradeElectronReceiptsCustomentrancesQueryRequest
from dg_sdk.request.v2_trade_electron_receipts_upload_request import V2TradeElectronReceiptsUploadRequest
from dg_sdk.request.v2_trade_electron_receipts_picture_upload_request import V2TradeElectronReceiptsPictureUploadRequest
from dg_sdk.request.v2_trade_electron_receipts_jumpinfo_request import V2TradeElectronReceiptsJumpinfoRequest
from dg_sdk.request.v2_invoice_mer_authqrcode_query_request import V2InvoiceMerAuthqrcodeQueryRequest
from dg_sdk.request.v2_invoice_mer_authqrcode_grant_request import V2InvoiceMerAuthqrcodeGrantRequest
from dg_sdk.request.v2_invoice_open_request import V2InvoiceOpenRequest
from dg_sdk.request.v2_invoice_queryapply_request import V2InvoiceQueryapplyRequest
from dg_sdk.request.v2_invoice_clerk_reg_request import V2InvoiceClerkRegRequest
from dg_sdk.request.v2_invoice_clerk_logon_request import V2InvoiceClerkLogonRequest
from dg_sdk.request.v2_invoice_mer_verifycode_upload_request import V2InvoiceMerVerifycodeUploadRequest
from dg_sdk.request.v2_invoice_mer_reg_request import V2InvoiceMerRegRequest
from dg_sdk.request.v2_invoice_mer_query_request import V2InvoiceMerQueryRequest
from dg_sdk.request.v2_invoice_mer_modify_request import V2InvoiceMerModifyRequest
from dg_sdk.request.v2_invoice_mer_status_query_request import V2InvoiceMerStatusQueryRequest
from dg_sdk.request.v2_invoice_permission_grant_request import V2InvoicePermissionGrantRequest
from dg_sdk.request.v2_invoice_permission_query_request import V2InvoicePermissionQueryRequest
from dg_sdk.request.v2_invoice_selfscanopen_request import V2InvoiceSelfscanopenRequest
from dg_sdk.request.v2_trade_trans_split_query_request import V2TradeTransSplitQueryRequest
from dg_sdk.request.v2_wallet_trade_recharge_card_request import V2WalletTradeRechargeCardRequest
from dg_sdk.request.v2_wallet_trade_query_request import V2WalletTradeQueryRequest
from dg_sdk.request.v2_wallet_password_reset_request import V2WalletPasswordResetRequest
from dg_sdk.request.v2_wallet_password_modify_request import V2WalletPasswordModifyRequest
from dg_sdk.request.v2_wallet_trade_order_close_request import V2WalletTradeOrderCloseRequest
from dg_sdk.request.v2_wallet_create_request import V2WalletCreateRequest
from dg_sdk.request.v2_wallet_query_request import V2WalletQueryRequest
from dg_sdk.request.v2_wallet_mobile_verify_request import V2WalletMobileVerifyRequest
from dg_sdk.request.v2_wallet_trade_withdrawal_request import V2WalletTradeWithdrawalRequest
from dg_sdk.request.v2_wallet_card_add_request import V2WalletCardAddRequest
from dg_sdk.request.v2_wallet_card_query_request import V2WalletCardQueryRequest
from dg_sdk.request.v2_wallet_trade_recharge_transfer_request import V2WalletTradeRechargeTransferRequest
from dg_sdk.request.v2_wallet_trade_pay_refund_request import V2WalletTradePayRefundRequest
from dg_sdk.request.v2_wallet_trade_pay_refund_query_request import V2WalletTradePayRefundQueryRequest
from dg_sdk.request.v2_wallet_trade_pay_balance_request import V2WalletTradePayBalanceRequest
from dg_sdk.request.v2_wallet_trade_transfer_request import V2WalletTradeTransferRequest
from dg_sdk.request.v2_pcredit_solution_create_request import V2PcreditSolutionCreateRequest
from dg_sdk.request.v2_trade_installment_payment_request import V2TradeInstallmentPaymentRequest
from dg_sdk.request.v2_pcredit_order_query_request import V2PcreditOrderQueryRequest
from dg_sdk.request.v2_pcredit_statue_modify_request import V2PcreditStatueModifyRequest
from dg_sdk.request.v2_pcredit_solution_modify_request import V2PcreditSolutionModifyRequest
from dg_sdk.request.v2_pcredit_solution_query_request import V2PcreditSolutionQueryRequest
from dg_sdk.request.v2_pcredit_certificate_config_request import V2PcreditCertificateConfigRequest
from dg_sdk.request.v2_trade_bankinstallmentinfo_query_request import V2TradeBankinstallmentinfoQueryRequest
from dg_sdk.request.v2_pcredit_fee_config_request import V2PcreditFeeConfigRequest
from dg_sdk.request.v2_pcredit_fee_detail_request import V2PcreditFeeDetailRequest
from dg_sdk.request.v2_hyc_personsign_create_request import V2HycPersonsignCreateRequest
from dg_sdk.request.v2_hyc_contract_query_request import V2HycContractQueryRequest
from dg_sdk.request.v2_hyc_invcategory_query_request import V2HycInvcategoryQueryRequest
from dg_sdk.request.v2_hyc_invinfo_query_request import V2HycInvinfoQueryRequest
from dg_sdk.request.v2_trade_lgwx_surrogate_request import V2TradeLgwxSurrogateRequest
from dg_sdk.request.v2_trade_lgwx_surrogate_query_request import V2TradeLgwxSurrogateQueryRequest
from dg_sdk.request.v2_hyc_mersign_query_request import V2HycMersignQueryRequest
from dg_sdk.request.v2_hyc_invoice_apply_request import V2HycInvoiceApplyRequest
from dg_sdk.request.v2_hyc_tax_query_request import V2HycTaxQueryRequest
from dg_sdk.request.v2_hyc_tax_download_request import V2HycTaxDownloadRequest
from dg_sdk.request.v2_trade_payment_micropay_request import V2TradePaymentMicropayRequest
from dg_sdk.request.v2_trade_payment_jspay_request import V2TradePaymentJspayRequest
from dg_sdk.request.v2_merchant_basicdata_settlement_query_request import V2MerchantBasicdataSettlementQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_closequery_request import V2TradePaymentScanpayClosequeryRequest
from dg_sdk.request.v2_trade_settle_collection_detail_query_request import V2TradeSettleCollectionDetailQueryRequest
from dg_sdk.request.v2_trade_settle_collection_rule_query_request import V2TradeSettleCollectionRuleQueryRequest
from dg_sdk.request.v2_trade_check_replay_request import V2TradeCheckReplayRequest
from dg_sdk.request.v2_trade_check_filequery_request import V2TradeCheckFilequeryRequest
from dg_sdk.request.v2_merchant_busi_bill_config_request import V2MerchantBusiBillConfigRequest
from dg_sdk.request.v2_merchant_busi_bill_query_request import V2MerchantBusiBillQueryRequest
from dg_sdk.request.v2_trade_settle_collection_rule_modify_request import V2TradeSettleCollectionRuleModifyRequest
from dg_sdk.request.v2_trade_settle_collection_rule_add_request import V2TradeSettleCollectionRuleAddRequest
from dg_sdk.request.v2_trade_acctpayment_balance_query_request import V2TradeAcctpaymentBalanceQueryRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirm_request import V2TradePaymentDelaytransConfirmRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmquery_request import V2TradePaymentDelaytransConfirmqueryRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmrefund_request import V2TradePaymentDelaytransConfirmrefundRequest
from dg_sdk.request.v2_trade_payment_delaytrans_confirmrefundquery_request import V2TradePaymentDelaytransConfirmrefundqueryRequest
from dg_sdk.request.v2_quickbuckle_query_request import V2QuickbuckleQueryRequest
from dg_sdk.request.v3_quickbuckle_confirm_request import V3QuickbuckleConfirmRequest
from dg_sdk.request.v3_quickbuckle_apply_request import V3QuickbuckleApplyRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_smscheck_request import V2TradeOnlinepaymentQuickpaySmscheckRequest
from dg_sdk.request.v2_quickbuckle_bind_cardinfo_query_request import V2QuickbuckleBindCardinfoQueryRequest
from dg_sdk.request.v2_quickbuckle_unbind_request import V2QuickbuckleUnbindRequest
from dg_sdk.request.v2_trade_onlinepayment_quickpay_frontpay_request import V2TradeOnlinepaymentQuickpayFrontpayRequest
from dg_sdk.request.v3_trade_onlinepayment_quickpay_smssend_request import V3TradeOnlinepaymentQuickpaySmssendRequest
from dg_sdk.request.v3_trade_onlinepayment_quickpay_pay_request import V3TradeOnlinepaymentQuickpayPayRequest
from dg_sdk.request.v2_trade_batchtranslog_query_request import V2TradeBatchtranslogQueryRequest
from dg_sdk.request.v2_trade_transstat_query_request import V2TradeTransstatQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_query_request import V2TradePaymentScanpayQueryRequest
from dg_sdk.request.v2_trade_payment_scanpay_close_request import V2TradePaymentScanpayCloseRequest
from dg_sdk.request.v2_trade_payment_scanpay_refund_request import V2TradePaymentScanpayRefundRequest
from dg_sdk.request.v2_trade_payment_scanpay_refundquery_request import V2TradePaymentScanpayRefundqueryRequest
from dg_sdk.request.v2_trade_payment_usermark2_query_request import V2TradePaymentUsermark2QueryRequest
from dg_sdk.request.v2_trade_settlement_enchashment_request import V2TradeSettlementEnchashmentRequest
from dg_sdk.request.v2_merchant_appeal_log_query_request import V2MerchantAppealLogQueryRequest
from dg_sdk.request.v2_merchant_appeal_relatedclue_query_request import V2MerchantAppealRelatedclueQueryRequest
from dg_sdk.request.v2_merchant_appeal_custinfo_query_request import V2MerchantAppealCustinfoQueryRequest
from dg_sdk.request.v2_merchant_appeal_list_query_request import V2MerchantAppealListQueryRequest
from dg_sdk.request.v2_merchant_appeal_fileurl_query_request import V2MerchantAppealFileurlQueryRequest
from dg_sdk.request.v2_merchant_appeal_common_submit_request import V2MerchantAppealCommonSubmitRequest
from dg_sdk.request.v2_merchant_appeal_detail_query_request import V2MerchantAppealDetailQueryRequest
from dg_sdk.request.v2_merchant_busi_modify_busistatus_request import V2MerchantBusiModifyBusistatusRequest
from dg_sdk.request.v2_merchant_complaint_complete_request import V2MerchantComplaintCompleteRequest
from dg_sdk.request.v2_merchant_complaint_reply_request import V2MerchantComplaintReplyRequest
from dg_sdk.request.v2_merchant_complaint_update_refundprogress_request import V2MerchantComplaintUpdateRefundprogressRequest
from dg_sdk.request.v2_merchant_complaint_download_picture_request import V2MerchantComplaintDownloadPictureRequest
from dg_sdk.request.v2_merchant_complaint_list_info_query_request import V2MerchantComplaintListInfoQueryRequest
from dg_sdk.request.v2_merchant_complaint_history_query_request import V2MerchantComplaintHistoryQueryRequest
from dg_sdk.request.v2_merchant_complaint_ali_riskinfo_query_request import V2MerchantComplaintAliRiskinfoQueryRequest
from dg_sdk.request.v2_merchant_complaint_request_certificates_request import V2MerchantComplaintRequestCertificatesRequest
from dg_sdk.request.v2_merchant_complaint_query_status_request import V2MerchantComplaintQueryStatusRequest
from dg_sdk.request.v2_merchant_complaint_submit_certificates_request import V2MerchantComplaintSubmitCertificatesRequest
from dg_sdk.request.v2_merchant_busi_at_modify_request import V2MerchantBusiAtModifyRequest
from dg_sdk.request.v2_merchant_busi_mercode_query_request import V2MerchantBusiMercodeQueryRequest
from dg_sdk.request.v2_merchant_basicdata_indv_request import V2MerchantBasicdataIndvRequest
from dg_sdk.request.v2_merchant_basicdata_ent_request import V2MerchantBasicdataEntRequest
from dg_sdk.request.v2_merchant_basicdata_sms_send_request import V2MerchantBasicdataSmsSendRequest
from dg_sdk.request.v2_merchant_activity_add_request import V2MerchantActivityAddRequest
from dg_sdk.request.v2_merchant_activity_query_request import V2MerchantActivityQueryRequest
from dg_sdk.request.v2_merchant_basicdata_modify_request import V2MerchantBasicdataModifyRequest
from dg_sdk.request.v2_supplementary_picture_request import V2SupplementaryPictureRequest
from dg_sdk.request.v2_merchant_url_forward_request import V2MerchantUrlForwardRequest
from dg_sdk.request.v2_merchant_busi_status_query_request import V2MerchantBusiStatusQueryRequest
from dg_sdk.request.v2_merchant_basicdata_query_request import V2MerchantBasicdataQueryRequest
from dg_sdk.request.v2_merchant_busi_open_request import V2MerchantBusiOpenRequest
from dg_sdk.request.v2_merchant_busi_modify_request import V2MerchantBusiModifyRequest
from dg_sdk.request.v2_merchant_busi_head_config_request import V2MerchantBusiHeadConfigRequest
from dg_sdk.request.v2_merchant_basicdata_status_query_request import V2MerchantBasicdataStatusQueryRequest
from dg_sdk.request.v2_merchant_busi_config_request import V2MerchantBusiConfigRequest
from dg_sdk.request.v2_merchant_busi_config_query_request import V2MerchantBusiConfigQueryRequest
from dg_sdk.request.v2_merchant_busi_realname_request import V2MerchantBusiRealnameRequest
from dg_sdk.request.v2_merchant_busi_realname_query_request import V2MerchantBusiRealnameQueryRequest
from dg_sdk.request.v2_quickbuckle_bank_query_request import V2QuickbuckleBankQueryRequest
from dg_sdk.request.v2_merchant_busi_ali_realname_query_request import V2MerchantBusiAliRealnameQueryRequest
from dg_sdk.request.v2_merchant_busi_ali_realname_apply_request import V2MerchantBusiAliRealnameApplyRequest
from dg_sdk.request.v2_trade_feecalc_request import V2TradeFeecalcRequest
from dg_sdk.request.v2_trade_onlinepayment_unionpay_request import V2TradeOnlinepaymentUnionpayRequest
from dg_sdk.request.v2_trade_wxusermark_query_request import V2TradeWxusermarkQueryRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_create_request import V2TradePayscoreServiceorderCreateRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_query_request import V2TradePayscoreServiceorderQueryRequest
from dg_sdk.request.v2_trade_payscore_deduct_query_request import V2TradePayscoreDeductQueryRequest
from dg_sdk.request.v2_trade_payscore_deduct_regitster_request import V2TradePayscoreDeductRegitsterRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_cancel_request import V2TradePayscoreServiceorderCancelRequest
from dg_sdk.request.v2_trade_payscore_serviceorder_complete_request import V2TradePayscoreServiceorderCompleteRequest
from dg_sdk.request.v2_trade_payscore_pay_payscorepay_request import V2TradePayscorePayPayscorepayRequest
from dg_sdk.request.v2_merchant_direct_wechat_settlementinfo_query_request import V2MerchantDirectWechatSettlementinfoQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_query_request import V2MerchantDirectWechatQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_subscribe_config_request import V2MerchantDirectWechatSubscribeConfigRequest
from dg_sdk.request.v2_merchant_direct_wechat_subscribe_query_request import V2MerchantDirectWechatSubscribeQueryRequest
from dg_sdk.request.v2_merchant_direct_wechat_sign_request import V2MerchantDirectWechatSignRequest
from dg_sdk.request.v2_merchant_direct_wechat_settlementinfo_modify_request import V2MerchantDirectWechatSettlementinfoModifyRequest
from dg_sdk.request.v2_merchant_direct_certinfo_add_request import V2MerchantDirectCertinfoAddRequest
from dg_sdk.request.v2_trade_onlinepayment_bankpay_payerquery_request import V2TradeOnlinepaymentBankpayPayerqueryRequest
from dg_sdk.request.v2_trade_onlinepayment_wappay_request import V2TradeOnlinepaymentWappayRequest
from dg_sdk.request.v2_trade_onlinepayment_bankpay_banklist_request import V2TradeOnlinepaymentBankpayBanklistRequest
from dg_sdk.request.v2_trade_onlinepayment_banking_frontpay_request import V2TradeOnlinepaymentBankingFrontpayRequest
from dg_sdk.request.v2_trade_onlinepayment_query_request import V2TradeOnlinepaymentQueryRequest
from dg_sdk.request.v2_trade_onlinepayment_refund_request import V2TradeOnlinepaymentRefundRequest
from dg_sdk.request.v2_trade_onlinepayment_refund_query_request import V2TradeOnlinepaymentRefundQueryRequest
from dg_sdk.request.v2_user_basicdata_indv_modify_request import V2UserBasicdataIndvModifyRequest
from dg_sdk.request.v2_user_basicdata_indv_request import V2UserBasicdataIndvRequest
from dg_sdk.request.v2_user_basicdata_ent_modify_request import V2UserBasicdataEntModifyRequest
from dg_sdk.request.v2_user_basicdata_ent_request import V2UserBasicdataEntRequest
from dg_sdk.request.v2_user_list_query_request import V2UserListQueryRequest
from dg_sdk.request.v2_user_apply_query_request import V2UserApplyQueryRequest
from dg_sdk.request.v2_user_basicdata_query_request import V2UserBasicdataQueryRequest
from dg_sdk.request.v2_user_busi_open_request import V2UserBusiOpenRequest
from dg_sdk.request.v2_user_busi_modify_request import V2UserBusiModifyRequest
from dg_sdk.request.v2_quickbuckle_onekey_cardbind_request import V2QuickbuckleOnekeyCardbindRequest
from dg_sdk.request.v2_trade_preauth_request import V2TradePreauthRequest
from dg_sdk.request.v2_trade_payment_preauthcancel_refund_request import V2TradePaymentPreauthcancelRefundRequest
from dg_sdk.request.v2_trade_preauthpay_request import V2TradePreauthpayRequest
from dg_sdk.request.v2_trade_payment_preauthpaycancel_refund_request import V2TradePaymentPreauthpaycancelRefundRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_query_request import V2TerminaldeviceDeviceinfoQueryRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_add_request import V2TerminaldeviceDeviceinfoAddRequest
from dg_sdk.request.v2_terminaldevice_deviceinfo_cancel_request import V2TerminaldeviceDeviceinfoCancelRequest
from dg_sdk.request.v2_terminaldevice_manage_bind_request import V2TerminaldeviceManageBindRequest
from dg_sdk.request.v2_terminaldevice_manage_unbind_request import V2TerminaldeviceManageUnbindRequest
from dg_sdk.request.v2_terminaldevice_manage_query_request import V2TerminaldeviceManageQueryRequest
from dg_sdk.request.v2_bill_ent_create_request import V2BillEntCreateRequest
from dg_sdk.request.v2_bill_ent_payer_query_request import V2BillEntPayerQueryRequest
from dg_sdk.request.v2_bill_ent_query_request import V2BillEntQueryRequest
from dg_sdk.request.v2_bill_ent_refund_request import V2BillEntRefundRequest
from dg_sdk.request.v2_bill_ent_refund_query_request import V2BillEntRefundQueryRequest
from dg_sdk.request.v2_bill_ent_changestat_request import V2BillEntChangestatRequest
from dg_sdk.request.v2_bill_ent_payer_delete_request import V2BillEntPayerDeleteRequest
from dg_sdk.request.v2_bill_ent_payer_update_request import V2BillEntPayerUpdateRequest
from dg_sdk.request.v2_bill_ent_payer_create_request import V2BillEntPayerCreateRequest
from dg_sdk.request.v2_merchant_direct_zft_receiver_config_request import V2MerchantDirectZftReceiverConfigRequest
from dg_sdk.request.v2_merchant_direct_zft_receiver_query_request import V2MerchantDirectZftReceiverQueryRequest
from dg_sdk.request.v2_merchant_direct_zft_reg_request import V2MerchantDirectZftRegRequest
from dg_sdk.request.v2_merchant_direct_alipay_applyorderstatus_query_request import V2MerchantDirectAlipayApplyorderstatusQueryRequest
from dg_sdk.request.v2_merchant_direct_alipay_appauthtoken_exchange_request import V2MerchantDirectAlipayAppauthtokenExchangeRequest
from dg_sdk.request.v2_merchant_direct_alipay_facetofacesign_apply_request import V2MerchantDirectAlipayFacetofacesignApplyRequest
from dg_sdk.request.v2_trade_payafteruse_installment_create_request import V2TradePayafteruseInstallmentCreateRequest
from dg_sdk.request.v2_trade_payafteruse_installment_refund_request import V2TradePayafteruseInstallmentRefundRequest
from dg_sdk.request.v2_trade_payafteruse_installment_refundquery_request import V2TradePayafteruseInstallmentRefundqueryRequest
from dg_sdk.request.v2_trade_payafteruse_installment_pay_request import V2TradePayafteruseInstallmentPayRequest
from dg_sdk.request.v2_trade_payafteruse_installment_query_request import V2TradePayafteruseInstallmentQueryRequest
from dg_sdk.request.v2_trade_payafteruse_creditbizorder_create_request import V2TradePayafteruseCreditbizorderCreateRequest
from dg_sdk.request.v2_trade_payafteruse_creditbizorder_query_request import V2TradePayafteruseCreditbizorderQueryRequest
from dg_sdk.request.v2_trade_payafteruse_creditbizorder_close_request import V2TradePayafteruseCreditbizorderCloseRequest
from dg_sdk.request.v2_merchant_settle_modify_request import V2MerchantSettleModifyRequest
from dg_sdk.request.v2_merchant_settle_config_request import V2MerchantSettleConfigRequest
from dg_sdk.request.v2_trade_cloudmis_device_information_mis_request import V2TradeCloudmisDeviceInformationMisRequest
from dg_sdk.request.v2_trade_cloudmis_order_detail_request import V2TradeCloudmisOrderDetailRequest
