from dg_sdk.core.request_tools import request_post
from dg_sdk.request.request_api_urls import V2_TRADE_PAYMENT_DELAYTRANS_CONFIRM



class V2TradePaymentDelaytransConfirmRequest(object):
    """
    交易确认接口
    """

    # 请求日期
    req_date = ""
    # 请求流水号
    req_seq_id = ""
    # 商户号
    huifu_id = ""
    # 交易类型**原交易为快捷支付必填：QUICK_PAY**，&lt;br/&gt;**原交易为余额支付必填：ACCT_PAYMENT**；&lt;br/&gt;&lt;font color&#x3D;&quot;green&quot;&gt;示例值：ACCT_PAYMENT&lt;/font&gt;
    pay_type = ""

    def post(self, extend_infos):
        """
        交易确认接口

        :param extend_infos: 扩展字段字典
        :return:
        """

        required_params = {
            "req_date":self.req_date,
            "req_seq_id":self.req_seq_id,
            "huifu_id":self.huifu_id,
            "pay_type":self.pay_type
        }
        required_params.update(extend_infos)
        return request_post(V2_TRADE_PAYMENT_DELAYTRANS_CONFIRM, required_params)
